==> blobAndConquer-0.8-2.tar.gz: blobAndConquer-0.8/src/hud/status.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void drawWidgets();
extern void moveMouseCursor();
extern void loadWidgets(char *filename);
extern void unitDropAllItems(Unit *unit);
extern void loadGameLocaleData(char *filename, bool append);
extern void addItemToList(ListView *listView, Entity *entity, bool showWeight);
extern void addStatToList(ListView *listView, char *statname, int position);
extern void addStatToList(ListView *listView, char *string, float value, int position);
extern void addStringToList(ListView *listView, char *string);
extern void addBlankLineToList(ListView *listView);
extern void drawGameObjects();
extern bool maxTimeIncreased(Unit *unit);
extern bool maxHealthIncreased(Unit *unit);
extern bool maxStrengthIncreased(Unit *unit);
extern bool maxStaminaIncreased(Unit *unit);
extern bool isExitSquare(Vector position);
extern char *getUnitStatus(Unit *unit);
extern GLColor getUnitHealthColor(Unit *unit);
extern Unit *findTeeka();

extern Audio *audio;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern LocaleManager *localeManager;
extern Map *map;
extern Mission *mission;
extern Mouse *mouse;
extern TextureManager *textureManager;
extern UIManager *uiManager;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/hud/status.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void drawWidgets();
extern void moveMouseCursor();
extern void loadWidgets(const char *filename);
extern void unitDropAllItems(Unit *unit);
extern void addItemToList(ListView *listView, Entity *entity, bool showWeight);
extern void addStatToList(ListView *listView, const char *statname, int position);
extern void addStatToList(ListView *listView, const char *string, float value, int position);
extern void addStringToList(ListView *listView, const char *string);
extern void addBlankLineToList(ListView *listView);
extern void drawGameObjects();
extern bool maxTimeIncreased(Unit *unit);
extern bool maxHealthIncreased(Unit *unit);
extern bool maxStrengthIncreased(Unit *unit);
extern bool maxStaminaIncreased(Unit *unit);
extern bool isExitSquare(Vector position);
extern char *getUnitStatus(Unit *unit);
extern GLColor getUnitHealthColor(Unit *unit);
extern Unit *findTeeka();

extern Audio *audio;
extern Camera *camera;
extern Engine *engine;
extern EntityManager *entityManager;
extern Game *game;
extern Graphics *graphics;
extern Map *map;
extern Mission *mission;
extern Mouse *mouse;
extern TextureManager *textureManager;
extern UIManager *uiManager;
